<?php
/*
 * Use a child theme for customization (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes).
 * @package WordPress - n/a
 * @subpackage amp
 * @since amp 0.4
 * © 2014 Larry Judd, Tradesouthwest.com
 */
include_once get_template_directory() . '/theme-customize.php';

function amp_setup() {
    
    // set width of external linked media players not defined
     global $content_width;
    if ( !isset( $content_width  ) ) {
        $content_width  = 720;
    }

    // custom editor style support
    add_editor_style( 'editor-style.css' );
    
    // This theme uses Featured Images (change size below by removing comment element)
    add_theme_support( 'post-thumbnails' ); 
	set_post_thumbnail_size( 250, 250 );

    // Add default posts and comments RSS feed links to head
    add_theme_support('automatic-feed-links');

    // for WordPress 4.1 and above only
    add_theme_support( 'title-tag' ); 

    // language support - add your translation
    load_theme_textdomain('amp', get_template_directory() . '/languages');

    // This theme uses wp_nav_menu in one location.
    register_nav_menus( array(
        'primary'   => __( 'Main Primary Navigation', 'amp' ),
	'secondary' => __( 'Secondary Mobile Navigation', 'amp' ),
	'footer'    => __( 'Secondary Footer Navigation', 'amp' )
        ) );     

    // supports custom header upload image
 	// Add a filter to image_width and image_height to change the width and height of your custom header.
	$custom_header_support = array(
	'default-image'  => get_template_directory_uri() . '/assets/logo-256.png',
	'random-default' => false,
    	'flex-height'    => true,
    	'flex-width'     => true,
    	'uploads'        => true,
    	'header-text'    => false,
	'width'          => 426,
	'height'         => 100,
	);

	add_theme_support( 'custom-header', $custom_header_support );
	
        /**
         * Custom background color and image support 
         */
	add_theme_support( 'custom-background' );
        $args = array(
            'default-color'          => 'FAFAFB',
            'default-image'          => '',	
        );
        add_theme_support( 'custom-background', $args );
}

add_action('after_setup_theme', 'amp_setup');

function amp_add_theme_scripts() {    
   
    // Loads default main stylesheet.
    wp_enqueue_style( 'amp-style', get_stylesheet_uri() ); 
    
    // Font awsome enqueue
    wp_enqueue_style( 'amp-font-awesome', get_template_directory_uri() .'/assets/fonts/css/font-awesome.css' );

    // Script to help html5 
    wp_enqueue_script( 'amp-modernizer-js', get_template_directory_uri() .'/assets/modernizr.js', array( 'jquery' ), '', true );

    // Script to call up mobile menu
    wp_enqueue_script( 'amp-mobile', get_template_directory_uri() . '/assets/amp-mobile.js', array('jquery'), '1.0.0', true );

     /*
      * Adds JavaScript to pages with the comment form to support
      * sites with threaded comments (when in use).
      */
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
	wp_enqueue_script( 'comment-reply' );  
}
    add_action( 'wp_enqueue_scripts', 'amp_add_theme_scripts' );

    // Add ie conditional html5 shim to header
function amp_add_ie_html5_shim () {
      echo "<!--[if lt IE 9]>\n";
        echo '<script src="', get_template_directory_uri() .'/assets/html5shiv.js"></script>'."\n";
        echo '<meta http-equiv="X-UA-Compatible" content="IE=9"/>'."\n";
        echo "<![endif]-->\n";
}
    add_action('wp_head', 'amp_add_ie_html5_shim');

/**
 * Creates a nicely formatted and more specific title element text
 * for output in head of document, based on current view.
 *
 * @since amp 0.4
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string Filtered title.
 */
function amp_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'amp' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'amp_wp_title', 10, 2 );

// the widget invoked here   
function amp_widgets_init() {
    register_sidebar(array(
            'name' => __('Primary Footer Widget Right Side', 'amp'),
            'id' => 'sidebar',
            'description' => __('The main footer widget area', 'amp'),
            'before_widget' => '<div id="%1$s" class="widget-container %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h3 class="widgettitle">',
            'after_title' => '</h3>',
        ));
}
add_action( 'widgets_init', 'amp_widgets_init' );

if ( ! function_exists( '_wp_render_title_tag' ) ) {
	function amp_render_title() {
?>
<title><?php wp_title( '|', true, 'right' ); ?></title>
<?php
	}
	add_action( 'wp_head', 'amp_render_title' );
}

?>